@@ -19,24 +19,33 @@ import re
 from astro.sql.table import Table
 
 
-def handle_table(t: Table):
-    return t.schema + "." + t.table_name if t.schema else t.table_name
+def _handle_table(t: Table):
+    """
+    returns the fully qualified name ("DATABASE"."SCHEMA"."TABLE").
+    This will allow snowflake users to do cross schema and cross database queries
+    :param t:
+    :return:
+    """
+
+    return t.database + "." + t.schema + "." + t.table_name
 
 
 def process_params(parameters):
     return {
-        k: (handle_table(v) if type(v) == Table else v) for k, v in parameters.items()
+        k: (_handle_table(v) if type(v) == Table else v) for k, v in parameters.items()
     }
 
 
-def _parse_template(sql, python_callable):
-    param_types = inspect.signature(python_callable).parameters
+def _parse_template(sql, python_callable, added_parameters):
+    param_types = inspect.signature(python_callable).parameters.copy()
+    param_types = {k: v.annotation for k, v in param_types.items()}
+    added_parameters = {k: type(v) for k, v in added_parameters.items()}
+    param_types.update(added_parameters)
     sql = sql.replace("{", "%(").replace("}", ")s")
     all_vals = re.findall("%\(.*?\)s", sql)
     mod_vals = {
         f: f"IDENTIFIER({f})"
-        if param_types.get(f[2:-2], None)
-        and param_types.get(f[2:-2], None).annotation == Table
+        if param_types.get(f[2:-2], None) and param_types.get(f[2:-2], None) == Table
         else f
         for f in all_vals
     }
